@@ -3,7 +3,6 @@
  * Test C++ interface to R's root finder.
  */
 RcppExport SEXP testRootFinder(SEXP x) {
-    SEXP ret = R_NilValue;
     BEGIN_RCPP
     double ysqr = Rcpp::as<double>(x);
     class PriceFunction : public cxxPack::Function1D {
@@ -15,7 +14,6 @@ RcppExport SEXP testRootFinder(SEXP x) {
     cxxPack::RootFinder1D rootFinder;
     PriceFunction pr(ysqr);
     double root = rootFinder.solve(pr, 0, 100, 0.00001);
-    ret = Rcpp::wrap(root);
+    return Rcpp::wrap(root);
     END_RCPP
-    return ret;
 }
