@@ -1,7 +1,6 @@
 #include <cxxPack.hpp>
 
 RcppExport SEXP My_Test(SEXP x_, SEXP df_) {
-    SEXP ret = R_NilValue;
     BEGIN_RCPP
 
     double x = Rcpp::as<double>(x_);
@@ -17,7 +16,6 @@ RcppExport SEXP My_Test(SEXP x_, SEXP df_) {
     rl["sqrtx"] = Rcpp::wrap(sqrt(x));
     rl["df1"] = Rcpp::wrap(df1);
     rl["df2"] = Rcpp::wrap(df2);
-    ret = rl;
+    return rl;
     END_RCPP
-    return ret;
 }
